@@ -101,7 +101,7 @@ class Token(UUIDable):
 
     expired_at = models.DateTimeField(pgettext_lazy('wcd_jwt', 'Expired at'))
     internal_expired_at = models.DateTimeField(
-        pgettext_lazy('wcd_jwt', 'Expired at'), editable=False,
+        pgettext_lazy('wcd_jwt', 'Expired at(internal)'), editable=False,
     )
 
     def __str__(self):
